@@ -268,7 +268,7 @@ class LiveCDCopyBackend(backend.AnacondaBackend):
             "floppy.floppy=", "all-generic-ide", "gentoo=", "res=", "hsync=",
             "refresh=", "noddc", "xdriver=", "onlyvesa", "nvidia=", "dodmraid",
             "dmraid", "sabayonmce", "steambox", "quiet", "scandelay=",
-            "doslowusb", "docrypt", "dokeymap", "keymap=", "radeon.modeset=",
+            "doslowusb", "dokeymap", "keymap=", "radeon.modeset=",
             "modeset=", "nomodeset", "domdadm"]
 
         # use reference, yeah
@@ -295,6 +295,7 @@ class LiveCDCopyBackend(backend.AnacondaBackend):
         if root_is_removable:
             cmdline.append("scandelay=10")
 
+        # TODO(lxnay): drop this when genkernel-next-39 is rolled out
         # check if root device is ext2, ext3 or ext4. In case,
         # add rootfstype=ext* to avoid genkernel crap to mount
         # it wrongly (for example: ext3 as ext2).
@@ -303,8 +304,10 @@ class LiveCDCopyBackend(backend.AnacondaBackend):
         if root_dev_type in ("ext2", "ext3", "ext4"):
             cmdline.append("rootfstype=" + root_dev_type)
 
-        # always add md support (we don't know if md have been created)
-        if "domdadm" not in cmdline:
+        raid_devs = self.anaconda.storage.mdarrays
+        raid_devs += self.anaconda.storage.mdcontainers
+        # only add domdadm if we managed to configure some kind of raid
+        if raid_devs and "domdadm" not in cmdline:
             cmdline.append("domdadm")
 
         # setup LVM
@@ -324,47 +327,47 @@ class LiveCDCopyBackend(backend.AnacondaBackend):
                         previous_vga = arg
 
         fsset = self.anaconda.storage.fsset
-        swap_devices = fsset.swapDevices
+        swap_devices = fsset.swapDevices or []
         # <storage.devices.Device> subclass
         root_device = self.anaconda.storage.rootDevice
         # device.format.mountpoint, device.format.type, device.format.mountable,
         # device.format.options, device.path, device.fstabSpec
-        root_crypted = False
-        swap_crypted = False
-        crypto_dev = None
         swap_crypto_dev = None
 
+        root_crypto_devs = []
         for name in fsset.cryptTab.mappings.keys():
-            crypto_dev = fsset.cryptTab[name]['device']
-            if root_device == crypto_dev or root_device.dependsOn(crypto_dev):
-                root_crypted = True
-                break
+            root_crypto_dev = fsset.cryptTab[name]['device']
+            if root_device == root_crypto_dev or \
+                    root_device.dependsOn(root_crypto_dev):
+                root_crypto_devs.append(root_crypto_dev)
 
-        crypt_root = None
-        if root_crypted:
-            log.info("Root crypted? %s, %s, crypto_dev: %s" % (root_crypted,
-                root_device.path, crypto_dev.fstabSpec))
+        log.info("Found root crypt devices: %s" % (root_crypto_devs,))
+        for root_crypto_dev in root_crypto_devs:
             # must use fstabSpec now, since latest genkernel supports it
-            final_cmdline.append("crypt_root=%s" % (crypto_dev.fstabSpec,))
+            final_cmdline.append("crypt_roots=%s" % (
+                    root_crypto_dev.fstabSpec,))
 
-        if swap_devices:
-            log.info("Found swap devices: %s" % (swap_devices,))
-            # TODO(lxnay): support multiple crypt_swap=
-            swap_dev = swap_devices[0]
 
+        log.info("Found swap devices: %s" % (swap_devices,))
+        for swap_dev in swap_devices:
+
+            log.info("Working on swap device: %s" % (swap_dev,))
+
+            this_swap_crypted = False
             for name in fsset.cryptTab.mappings.keys():
                 swap_crypto_dev = fsset.cryptTab[name]['device']
                 swap_depends = swap_dev.dependsOn(swap_crypto_dev)
-                log_s = "Checking cryptTab name=%s, swap_crypto_dev=%s {%s}, "
-                log_s += "crypto_dev=%s {%s}, swap_dev.dependsOn(swap)=%s"
+                log_s = "Checking cryptTab name=%s, swap_dev=%s,"
+                log_s += "swap_crypto_dev=%s {%s}, "
+                log_s += "swap_dev.dependsOn(swap)=%s"
                 log.info(log_s % (
-                        name, swap_crypto_dev, swap_crypto_dev.fstabSpec,
-                        crypto_dev, crypto_dev.fstabSpec, swap_depends))
+                        name, swap_dev, swap_crypto_dev,
+                        swap_crypto_dev.fstabSpec, swap_depends))
                 if swap_dev == swap_crypto_dev or swap_depends:
-                    swap_crypted = True
+                    this_swap_crypted = True
                     break
 
-            log.info("swap_crypted set to %s" % (swap_crypted,))
+            log.info("this_swap_crypted set to %s" % (this_swap_crypted,))
 
             # Use .path instead of fstabSpec for cmdline because
             # genkernel must create an appropriate device node
@@ -372,26 +375,23 @@ class LiveCDCopyBackend(backend.AnacondaBackend):
             # so that the generic /dev/mapper/swap will not be used
             # and systemd won't shit in its pants.
             final_cmdline.append("resume=%s" % (swap_dev.path,))
-            if swap_crypted:
+            if this_swap_crypted:
                 add_crypt_swap = True
-                if root_crypted and crypto_dev is not None:
-                    if crypto_dev.fstabSpec == swap_crypto_dev.fstabSpec:
+                for root_crypto_dev in root_crypto_devs:
+                    if root_crypto_dev.fstabSpec == swap_crypto_dev.fstabSpec:
                         # due to genkernel initramfs stupidity,
                         # when crypt_root = crypt_swap
                         # do not add crypt_swap.
                         add_crypt_swap = False
+                        break
 
                 if add_crypt_swap:
                     # must use fstabSpec now, since latest genkernel supports it
                     final_cmdline.append(
-                        "crypt_swap=%s" % (swap_crypto_dev.fstabSpec,))
+                        "crypt_swaps=%s" % (swap_crypto_dev.fstabSpec,))
                 else:
                     log.info("Not adding crypt_swap= because "
-                             "crypto_dev == swap_crypto_dev")
-
-        # always add docrypt, loads kernel mods required by cryptsetup devices
-        if "docrypt" not in final_cmdline:
-            final_cmdline.append("docrypt")
+                             "swap_crypto_dev is in root_crypto_devs")
 
         log.info("Generated boot cmdline: %s" % (final_cmdline,))
         return final_cmdline
